@@ -8,7 +8,7 @@
 #' 
 #' 
 #' \tabular{ll}{ Package: \tab crawl\cr Type: \tab Package\cr Version: \tab
-#' 1.3-2\cr Date: \tab 2011-11-21\cr License: \tab Unlimited \cr LazyLoad: \tab
+#' 1.3-4\cr Date: \tab 2012-4-7\cr License: \tab Unlimited \cr LazyLoad: \tab
 #' yes\cr }
 #' 
 #' @name crawl-package
@@ -147,24 +147,12 @@ NULL
 
 .onLoad <- function(library, pkgname)
 {
-  ## Return a list, each element of which is a vector
-  ## the first element of the vector is the stuff before the colon in info[[1]]
-  ## the second element is the stuff after the colon (can get > 2 elements some
-  ## times but ignore)
-  info <- strsplit(library(help=pkgname, character.only=TRUE)$info[[1]], "\\:[ ]+")
-  ## Go through the list, pulling out the Package, Version and Built strings
-  l <- length(info)
-  package <- version <- built <- ""
-  for (i in 1:l) {
-    if(info[[i]][1] == "Package") package <- info[[i]][2]
-    if(info[[i]][1] == "Version") version <- info[[i]][2]
-    if(info[[i]][1] == "Built") built <- info[[i]][2]
-  }
-  ## Print these out
-  packageStartupMessage(paste("This is", package, version, "\nBuilt:", built, "\n"))
-  ## uncomment for fortran/c code
-  ## library.dynam("filenameForDll", pkgname)
-  #library.dynam("crawl", pkgname)
+  info <-utils::packageDescription(pkgname)
+  package <- info$Package
+  version <- info$Version
+  date <- info$Date
+  packageStartupMessage(paste("\n", package, version, paste("(",date, ")", sep=""), "\n"))
+
 }
 
 .onUnload <- function(libpath)
